==> phpMyGPX-0.1.tar.bz2: phpmygpx/traces.html.php <==
<?php
/**
* @version $Id: $
* @package osm-things
* @copyright Copyright (C) 2008 Sebastian Klemm.
* @license http://www.gnu.org/copyleft/gpl.html GNU/GPL, see LICENSE.php
*/

include("./config.inc.php");

class HTML_traces {
    function viewGpxDetails($gpx) {
    	global $cfg;
    	echo "<b>". _CMN_FILE_NAME .":</b> ". $gpx['name'] ."<br />\n";
    	echo "<b>". _CMN_FILE_SIZE .":</b> ". (round($gpx['size']/1024, 1)) ." kB<br />\n";
    	echo "<b>". _CMN_DESCRIPTION .":</b> ". $gpx['description'] ."<br />\n";
    }

    function viewGpxDetailsTable($gpx) {
    	global $cfg;
		echo "<table><tr><td>";
		echo "<table class='data'>";
        echo "<tr class='head'><th></th><th>MIN</th><th>AVG</th>
        	<th>MAX</th></tr>\n";
		echo "<tr><td>"._CMN_LAT."</td><td>".($gpx['minlat']/1000000)."</td><td>"
			.($gpx['avglat']/1000000)."</td><td>".($gpx['maxlat']/1000000)."</td></tr>\n";
		echo "<tr><td>"._CMN_LON."</td><td>".($gpx['minlon']/1000000)."</td><td>"
			.($gpx['avglon']/1000000)."</td><td>".($gpx['maxlon']/1000000)."</td></tr>\n";
		echo "<tr><td>"._CMN_ALT."</td><td>$gpx[minalt]</td><td>$gpx[avgalt]</td>
			<td>$gpx[maxalt]</td></tr>\n";
		echo "<tr><td>"._CMN_DATE."</td><td>$gpx[mints]</td><td></td>
			<td>$gpx[maxts]</td></tr>\n";
		echo "<tr><td>"._CMN_FIX."</td><td>$gpx[minfix]</td><td>$gpx[avgfix]</td>
			<td>$gpx[maxfix]</td></tr>\n";
		echo "<tr><td>"._CMN_SAT."</td><td>$gpx[minsat]</td><td>$gpx[avgsat]</td>
			<td>$gpx[maxsat]</td></tr>\n";
		echo "<tr><td>"._CMN_HDOP."</td><td>$gpx[minhdop]</td><td>$gpx[avghdop]</td>
			<td>$gpx[maxhdop]</td></tr>\n";
		echo "<tr><td>"._CMN_PDOP."</td><td>$gpx[minpdop]</td><td>$gpx[avgpdop]</td>
			<td>$gpx[maxpdop]</td></tr>\n";
		echo "</table>\n";
		echo "</td><td style='padding-left:20px;'>\n";
		if(0) {
			echo '<a href="./image.php?type=birdview&id='.$gpx['gpx_id'].
				'&width='.$cfg['image_big_size'].'&height='.$cfg['image_big_size'].'">
				<img src="files/gpx_'.$gpx['gpx_id'].'.png"'.
				'width="'.$cfg['image_size'].'" height="'.$cfg['image_size'].'" '.
				'border="1" alt="GPX Trace" /></a>';
			echo '<a href="./image.php?type=altitude&id='.$gpx['gpx_id'].
				'&width='.$cfg['image_big_size'].'&height='.$cfg['image_big_size'].'">
				<img src="files/gpx_'.$gpx['gpx_id'].'_alt.png"'.
				'width="'.$cfg['image_size'].'" height="'.$cfg['image_size'].'" '.
				'border="1" alt="GPX Altitude Profile" /></a>';
		}else {
			echo '<a href="./image.php?type=birdview&id='.$gpx['gpx_id'].
				'&width='.$cfg['image_big_size'].'&height='.$cfg['image_big_size'].'">
				<img src="./image.php?type=birdview&id='.$gpx['gpx_id'].
				'&width='.$cfg['image_size'].'&height='.$cfg['image_size'].'"'.
				'width="'.$cfg['image_size'].'" height="'.$cfg['image_size'].'" '.
				'border="1" alt="GPX Trace" /></a>';
			echo '<a href="./image.php?type=altitude&id='.$gpx['gpx_id'].
				'&width='.$cfg['image_big_size'].'&height='.$cfg['image_big_size'].'">
				<img src="./image.php?type=altitude&id='.$gpx['gpx_id'].
				'&width='.$cfg['image_size'].'&height='.$cfg['image_size'].'"'.
				'width="'.$cfg['image_size'].'" height="'.$cfg['image_size'].'" '.
				'border="1" alt="GPX Altitude Profile" /></a>';
		}
		echo "</td></tr></table>\n";
		/*    	
    	echo "<a target='_blank' href='http://www.openstreetmap.org/?minlat="
    		. ($gpx['minlat']/1000000) ."&maxlat=". ($gpx['maxlat']/1000000) 
    		."&minlon=". ($gpx['minlon']/1000000) ."&maxlon=". ($gpx['maxlon']/1000000) 
    		."&layers=B00FTF'>". _TRC_SHOW_OSM_MAP ."</a>\n";
    	echo "<br />";
    	*/
    	echo "<a target='_self' href='map.php?id=".$gpx['gpx_id']
    		."'>". _TRC_SHOW_OSM_MAP ."</a>\n";
	}

    function viewGpxTableHeader() {
		echo "<table class='data'>";
        echo "<tr class='head'><th>"._CMN_GPX_ID."</th>
        	<th>"._CMN_FILE_NAME."</th><th>"._CMN_FILE_SIZE."</th>
			<th>"._CMN_DATE."</th>
			<th>"._CMN_DESCRIPTION."</th></tr>\n";
		/*
        echo "<tr class='head'><th>"._CMN_GPX_ID."</th><th>"._CMN_USER_ID."</th>
        	<th>"._CMN_VISIBLE."</th>
        	<th>"._CMN_FILE_NAME."</th><th>"._CMN_FILE_SIZE."</th>
        	<th>"._CMN_LAT."</th><th>"._CMN_LON."</th>
			<th>"._CMN_DATE."</th><th>"._CMN_PUBLIC."</th>
			<th>"._CMN_DESCRIPTION."</th><th>"._CMN_INSERTED."</th></tr>\n";
		*/
	}

    function viewGpxTableRow($gpx) {
		echo "<tr><td>$gpx[id]</td>
			<td>$gpx[name]</td><td>$gpx[size]</td>
			<td>$gpx[timestamp]</td>
			<td>$gpx[description]</td>
			<td><a href='?task=view&id=$gpx[id]'><img src='images/b_browse.png' title='"._MENU_TRKPT_VIEW."' border='0' /></a></td>
			<td><a href='?task=details&id=$gpx[id]'><img src='images/b_view.png' title='"._MENU_GPX_DETAILS."' border='0' /></a></td>
			<td><a href='files/$gpx[name]'><img src='images/b_export.png' title='"._MENU_GPX_DOWNL."' border='0' /></a></td>
			<td><a href='?task=delete&id=$gpx[id]'><img src='images/b_drop.png' title='"._MENU_GPX_DELETE."' border='0' /></a></td></tr>\n";
		/*
		echo "<tr><td>$gpx[id]</td><td>$gpx[user_id]</td><td>$gpx[visible]</td>
			<td>$gpx[name]</td><td>$gpx[size]</td>
			<td>$gpx[latitude]</td><td>$gpx[longitude]</td><td>$gpx[timestamp]</td>
			<td>$gpx[public]</td><td>$gpx[description]</td><td>$gpx[inserted]</td>
			<td><a href='?task=view&id=$gpx[id]'><img src='images/b_browse.png' title='"._MENU_TRKPT_VIEW."' border='0' /></a></td>
			<td><a href='?task=details&id=$gpx[id]'><img src='images/b_view.png' title='"._MENU_GPX_DETAILS."' border='0' /></a></td>
			<td><a href='files/$gpx[name]'><img src='images/b_export.png' title='"._MENU_GPX_DOWNL."' border='0' /></a></td>
			<td><a href='?task=delete&id=$gpx[id]'><img src='images/b_drop.png' title='"._MENU_GPX_DELETE."' border='0' /></a></td></tr>\n";
		*/
	}

    function viewGpxTableFooter() {
		echo "</table>\n";
	}

    function viewTraceTableHeader() {
		echo "<table class='data'>";
        echo "<tr class='head'><th>"._CMN_GPX_ID."</th><th>"._CMN_DATE."</th>
        	<th>"._CMN_LAT."</th><th>"._CMN_LON."</th>
        	<th>"._CMN_FIX."</th><th>"._CMN_SAT."</th>
        	<th>"._CMN_HDOP."</th><th>"._CMN_PDOP."</th>
			<th>"._CMN_ALT."</th><th>"._CMN_COURSE."</th><th>"._CMN_SPEED."</th></tr>\n";
	}

    function viewTraceTableRow($tp) {
		echo "<tr><td>$tp[gpx_id]</td><td>$tp[timestamp]</td>
			<td>".($tp['latitude']/1000000)."</td><td>".($tp['longitude']/1000000)."</td>
			<td>$tp[fix]</td><td>$tp[sat]</td>
			<td>$tp[hdop]</td><td>$tp[pdop]</td><td>$tp[altitude]</td>
			<td>$tp[course]</td><td>$tp[speed]</td></tr>\n";
	}

    function viewTraceTableFooter() {
		echo "</table>\n";
	}

	function fileUploadForm($url, $maxfilesize) {
        echo "<form enctype='multipart/form-data' method='post' action='$url' class='filter'>\n";
		echo _TRC_CHOOSE_UPL_FILE ."<br />\n";
		echo '<input type="hidden" name="MAX_FILE_SIZE" value="'.$maxfilesize.'">';
		echo '<input type="file" name="userfile" size=40><br />';
		echo _CMN_DESCRIPTION .': <input type="text" name="description" size=80>';
        echo "<input type='button' name='submit_btn' value='"._CMN_CONTINUE."' onClick='submit();'>\n";
        echo "</form>\n";
	}

	function searchGpxForm($url) {
        echo "<form method='get' action='$url' class='filter'>\n";
		echo _TRC_CHOOSE_SEARCH_FILTER ."<br />\n";
		echo '<input type="hidden" name="task" value="gpx">';
		echo '<input type="hidden" name="option" value="search">';
		echo _CMN_DESCRIPTION .': <input type="text" name="description" size="32">';
        echo "<input type='button' name='submit_btn' value='"._CMN_CONTINUE."' onClick='submit();'>\n";
        echo "</form>\n";
	}

	function searchTrkPtForm($url) {
        echo "<form method='get' action='$url' class='filter'>\n";
        echo "<table border=0><tr><td colspan=4>";
		echo _TRC_CHOOSE_SEARCH_FILTER ."<br />\n";
		echo _TRC_USE_DP_FOR_SEARCH ."<br />\n";
		echo '<input type="hidden" name="task" value="view">';
		echo '<input type="hidden" name="option" value="search">';
		echo "</td></tr><tr>";
		echo '<td>'. _CMN_DATE .': </td><td><input type="text" name="date"></td>';
		echo "</tr><tr>";
		echo '<td>'. _CMN_LAT .': </td><td><input type="text" name="lat"></td>';
		echo '<td>'. _CMN_RANGE .': </td><td><input type="text" name="lat_range"></td>';
		echo "</tr><tr>";
		echo '<td>'. _CMN_LON .': </td><td><input type="text" name="lon"></td>';
		echo '<td>'. _CMN_RANGE .': </td><td><input type="text" name="lon_range"></td>';
		echo "</tr><tr>";
        echo "<td><input type='button' name='submit_btn' value='"._CMN_CONTINUE."' onClick='submit();'>\n";
        echo "</td></tr></table>";
        echo "</form>\n";
	}

    function deleteForm($url, $id) {
        echo "<form method='post' action='$url' class='filter'>\n";
        echo "<h3 style='font-weight:bold;color:red;'>"._CMN_WARNING."</h3>\n";
		echo "<p>"._MENU_GPX." # $id:<br />"._TRC_REALLY_DELETE."</p>\n";
		echo "<p>"._TRC_CONFIRM_DELETE."</p>\n";
        echo "<input type='text' name='confirm' value='"._CMN_NO."'>\n";
        echo "<input type='submit' name='submit_btn' value='"._MENU_GPX_DELETE."' onClick='submit();'>\n";
        echo "<input type='hidden' name='submit' value='delete'>\n";
        echo "\n";
        echo "</form>\n";
    }
}
?>

==> phpMyGPX-0.2.tar.bz2: phpmygpx/traces.html.php <==
<?php
/**
* @version $Id: $
* @package osm-things
* @copyright Copyright (C) 2008 Sebastian Klemm.
* @license http://www.gnu.org/copyleft/gpl.html GNU/GPL, see LICENSE.php
*/

include("./config.inc.php");

class HTML_traces {
    function viewGpxDetails($gpx) {
    	echo "<b>". _CMN_FILE_NAME .":</b> ". $gpx['name'] ."<br />\n";
    	echo "<b>". _CMN_FILE_SIZE .":</b> ". (round($gpx['size']/1024, 1)) ." kB<br />\n";
    	echo "<b>". _CMN_DESCRIPTION .":</b> ". $gpx['description'] ."<br />\n";
    }

    function viewGpxDetailsTable($gpx) {
    	global $cfg;
		echo "<table><tr><td>";
		echo "<table class='data'>";
        echo "<tr class='head'><th></th><th>MIN</th><th>AVG</th>
        	<th>MAX</th></tr>\n";
		echo "<tr><td>"._CMN_LAT."</td><td>".($gpx['minlat']/1000000)."</td><td>"
			.($gpx['avglat']/1000000)."</td><td>".($gpx['maxlat']/1000000)."</td></tr>\n";
		echo "<tr><td>"._CMN_LON."</td><td>".($gpx['minlon']/1000000)."</td><td>"
			.($gpx['avglon']/1000000)."</td><td>".($gpx['maxlon']/1000000)."</td></tr>\n";
		echo "<tr><td>"._CMN_ALT."</td><td>$gpx[minalt]</td><td>$gpx[avgalt]</td>
			<td>$gpx[maxalt]</td></tr>\n";
		echo "<tr><td>"._CMN_DATE."</td><td>$gpx[mints]</td><td></td>
			<td>$gpx[maxts]</td></tr>\n";
		echo "<tr><td>"._CMN_FIX."</td><td>$gpx[minfix]</td><td>$gpx[avgfix]</td>
			<td>$gpx[maxfix]</td></tr>\n";
		echo "<tr><td>"._CMN_SAT."</td><td>$gpx[minsat]</td><td>$gpx[avgsat]</td>
			<td>$gpx[maxsat]</td></tr>\n";
		echo "<tr><td>"._CMN_HDOP."</td><td>$gpx[minhdop]</td><td>$gpx[avghdop]</td>
			<td>$gpx[maxhdop]</td></tr>\n";
		echo "<tr><td>"._CMN_PDOP."</td><td>$gpx[minpdop]</td><td>$gpx[avgpdop]</td>
			<td>$gpx[maxpdop]</td></tr>\n";
			
		echo "</table>\n";
		echo "</td><td style='padding-left:20px;'>\n";
		echo '<a href="./image.php?type=birdview&id='.$gpx['gpx_id'].
			'&width='.$cfg['image_big_size'].'&height='.$cfg['image_big_size'].'">
			<img src="./image.php?type=birdview&id='.$gpx['gpx_id'].
			'&width='.$cfg['image_size'].'&height='.$cfg['image_size'].'"'.
			'width="'.$cfg['image_size'].'" height="'.$cfg['image_size'].'" '.
			'border="1" alt="GPX Trace" /></a>';
		echo '<a href="./image.php?type=altitude&id='.$gpx['gpx_id'].
			'&width='.$cfg['image_big_size'].'&height='.$cfg['image_big_size'].'">
			<img src="./image.php?type=altitude&id='.$gpx['gpx_id'].
			'&width='.$cfg['image_size'].'&height='.$cfg['image_size'].'"'.
			'width="'.$cfg['image_size'].'" height="'.$cfg['image_size'].'" '.
			'border="1" alt="GPX Altitude Profile" /></a>';
		echo "</td></tr></table>\n";
		/*    	
    	echo "<a target='_blank' href='http://www.openstreetmap.org/?minlat="
    		. ($gpx['minlat']/1000000) ."&maxlat=". ($gpx['maxlat']/1000000) 
    		."&minlon=". ($gpx['minlon']/1000000) ."&maxlon=". ($gpx['maxlon']/1000000) 
    		."&layers=B00FTF'>". _TRC_SHOW_OSM_MAP ."</a>\n";
    	echo "<br />";
    	*/
    	echo "<a target='_self' href='map.php?id=".$gpx['gpx_id']
    		."'>". _TRC_SHOW_MAP ."</a><br />\n";
	}

    function viewGpxDistances($dist) {
    	if(sizeof($dist) > 2) {
			echo "<table class='data'>";
	    	foreach($dist as $key=>$val) {
	    		if(!$key)
	    			continue;
	    		echo "<tr><td>";
	    		echo _TRC_TRACK. ($key) ."</td><td>". round($val[0], 1) ." km (";
	    		echo round($val[0] / ($val[1] - $dist[$key-1][2]) * 3600, 1)
	    			." km/h)</td><td>";
	    		echo ($val[1] - $dist[$key-1][2]) ." s</td><td>(".
    				strftime(_DATE_FORMAT_LC3, $dist[$key-1][2]) ." - ".
    				strftime(_DATE_FORMAT_LC3, $val[1]) .")";
	    		echo "</td></tr>\n";
	    		if($val[2]) {
	    			echo "<tr class='odd'><td>";
	    			echo _TRC_HALT ."</td><td></td><td>". ($val[2] - $val[1])
	    				." s </td><td>(".
	    				strftime(_DATE_FORMAT_LC3, $val[1]) ." - ".
	    				strftime(_DATE_FORMAT_LC3, $val[2]) .")";
	    			echo "</td></tr>\n";
	    		}
	    	}
	    	echo "</td></tr></table>\n";
    	}
    	echo "<b>". _TRC_APPROX_DIST .":</b> ". round(array_sum_multidim($dist, NULL, 0),
    		2) ." km<br />\n";

		// total trip time and average speed calculation
		foreach($dist as $key=>$val)
			$track_time += $val[1] - $val[2];
		$speed = round(array_sum_multidim($dist, NULL, 0) / $track_time * 3600, 2);
		
    	echo "<b>". _TRC_TRIP_TIME .":</b> ". time_format($track_time, _TIME_FORMAT_LC4)
    		." ($track_time s)<br />\n";
    	echo "<b>". _TRC_AVG_SPEED .":</b> ". round($speed, 2) ." km/h<br />\n";
    }

    function viewGpxTableHeader() {
		echo "<table class='data'>";
        echo "<tr class='head'><th>"._CMN_GPX_ID."</th>
        	<th>"._CMN_FILE_NAME."</th><th>"._CMN_FILE_SIZE."</th>
			<th>"._CMN_DATE."</th>
			<th>"._CMN_DESCRIPTION."</th></tr>\n";
		/*
        echo "<tr class='head'><th>"._CMN_GPX_ID."</th><th>"._CMN_USER_ID."</th>
        	<th>"._CMN_VISIBLE."</th>
        	<th>"._CMN_FILE_NAME."</th><th>"._CMN_FILE_SIZE."</th>
        	<th>"._CMN_LAT."</th><th>"._CMN_LON."</th>
			<th>"._CMN_DATE."</th><th>"._CMN_PUBLIC."</th>
			<th>"._CMN_DESCRIPTION."</th><th>"._CMN_INSERTED."</th></tr>\n";
		*/
	}

    function viewGpxTableRow($gpx) {
		echo "<tr><td>$gpx[id]</td>
			<td>$gpx[name]</td><td>$gpx[size]</td>
			<td>$gpx[timestamp]</td>
			<td>$gpx[description]</td>
			<td><a href='?task=view&id=$gpx[id]'><img src='images/b_browse.png' title='"._MENU_TRKPT_VIEW."' border='0' /></a></td>
			<td><a href='?task=details&id=$gpx[id]'><img src='images/b_view.png' title='"._MENU_GPX_DETAILS."' border='0' /></a></td>
			<td><a href='files/$gpx[name]'><img src='images/b_export.png' title='"._MENU_GPX_DOWNL."' border='0' /></a></td>
			<td><a href='?task=delete&id=$gpx[id]'><img src='images/b_drop.png' title='"._MENU_GPX_DELETE."' border='0' /></a></td></tr>\n";
		/*
		echo "<tr><td>$gpx[id]</td><td>$gpx[user_id]</td><td>$gpx[visible]</td>
			<td>$gpx[name]</td><td>$gpx[size]</td>
			<td>$gpx[latitude]</td><td>$gpx[longitude]</td><td>$gpx[timestamp]</td>
			<td>$gpx[public]</td><td>$gpx[description]</td><td>$gpx[inserted]</td>
			<td><a href='?task=view&id=$gpx[id]'><img src='images/b_browse.png' title='"._MENU_TRKPT_VIEW."' border='0' /></a></td>
			<td><a href='?task=details&id=$gpx[id]'><img src='images/b_view.png' title='"._MENU_GPX_DETAILS."' border='0' /></a></td>
			<td><a href='files/$gpx[name]'><img src='images/b_export.png' title='"._MENU_GPX_DOWNL."' border='0' /></a></td>
			<td><a href='?task=delete&id=$gpx[id]'><img src='images/b_drop.png' title='"._MENU_GPX_DELETE."' border='0' /></a></td></tr>\n";
		*/
	}

    function viewGpxTableFooter() {
		echo "</table>\n";
	}

    function viewTraceTableHeader() {
		echo "<table class='data'>";
        echo "<tr class='head'><th>"._CMN_GPX_ID."</th><th>"._CMN_DATE."</th>
        	<th>"._CMN_LAT."</th><th>"._CMN_LON."</th>
        	<th>"._CMN_FIX."</th><th>"._CMN_SAT."</th>
        	<th>"._CMN_HDOP."</th><th>"._CMN_PDOP."</th>
			<th>"._CMN_ALT."</th><th>"._CMN_COURSE."</th><th>"._CMN_SPEED."</th></tr>\n";
	}

    function viewTraceTableRow($tp) {
    	$lat = $tp['latitude']/1000000;
    	$lon = $tp['longitude']/1000000;
		echo "<tr><td><a href='traces.php?task=details&id=$tp[gpx_id]'>$tp[gpx_id]
			</a></td><td>$tp[timestamp]</td>
			<td><a href='map.php?lat=$lat&lon=$lon&zoom=17&marker=1'>$lat</td>
			<td><a href='map.php?lat=$lat&lon=$lon&zoom=17&marker=1'>$lon</td>
			<td>$tp[fix]</td><td>$tp[sat]</td>
			<td>$tp[hdop]</td><td>$tp[pdop]</td><td>$tp[altitude]</td>
			<td>$tp[course]</td><td>$tp[speed]</td></tr>\n";
	}

    function viewTraceTableFooter() {
		echo "</table>\n";
	}

	function fileUploadForm($url, $maxfilesize) {
        echo "<form enctype='multipart/form-data' method='post' action='$url' class='filter'>\n";
		echo _TRC_CHOOSE_UPL_FILE ."<br />\n";
		echo '<input type="hidden" name="MAX_FILE_SIZE" value="'.$maxfilesize.'">';
		echo '<input type="file" name="userfile" size=40><br />';
		echo _CMN_DESCRIPTION .': <input type="text" name="description" size=80>';
        echo "<input type='button' name='submit_btn' value='"._CMN_CONTINUE."' onClick='submit();'>\n";
        echo "</form>\n";
	}

	function searchGpxForm($url) {
        echo "<form method='get' action='$url' class='filter'>\n";
		echo _TRC_CHOOSE_SEARCH_FILTER ."<br />\n";
		echo '<input type="hidden" name="task" value="gpx">';
		echo '<input type="hidden" name="option" value="search">';
		echo _CMN_DESCRIPTION .': <input type="text" name="description" size="32">';
        echo "<input type='button' name='submit_btn' value='"._CMN_CONTINUE."' onClick='submit();'>\n";
        echo "</form>\n";
	}

	function searchTrkPtForm($url) {
        echo "<form method='get' action='$url' class='filter'>\n";
        echo "<table border=0><tr><td colspan=4>";
		echo _TRC_CHOOSE_SEARCH_FILTER ."<br />\n";
		echo _TRC_USE_DP_FOR_SEARCH ."<br />\n";
		echo '<input type="hidden" name="task" value="view">';
		echo '<input type="hidden" name="option" value="search">';
		echo "</td></tr><tr>";
		echo '<td>'. _CMN_DATE .': </td><td><input type="text" name="date"></td>';
		echo "</tr><tr>";
		echo '<td>'. _CMN_LAT .': </td><td><input type="text" name="lat"></td>';
		echo '<td>'. _CMN_RANGE .': </td><td><input type="text" name="lat_range"></td>';
		echo "</tr><tr>";
		echo '<td>'. _CMN_LON .': </td><td><input type="text" name="lon"></td>';
		echo '<td>'. _CMN_RANGE .': </td><td><input type="text" name="lon_range"></td>';
		echo "</tr><tr>";
        echo "<td><input type='button' name='submit_btn' value='"._CMN_CONTINUE."' onClick='submit();'>\n";
        echo "</td></tr></table>";
        echo "</form>\n";
	}

    function deleteForm($url, $id) {
        echo "<form method='post' action='$url' class='filter'>\n";
        echo "<h3 style='font-weight:bold;color:red;'>"._CMN_WARNING."</h3>\n";
		echo "<p>"._MENU_GPX." # $id:<br />"._TRC_REALLY_DELETE."</p>\n";
		echo "<p>"._TRC_CONFIRM_DELETE."</p>\n";
        echo "<input type='text' name='confirm' value='"._CMN_NO."'>\n";
        echo "<input type='submit' name='submit_btn' value='"._MENU_GPX_DELETE."' onClick='submit();'>\n";
        echo "<input type='hidden' name='submit' value='delete'>\n";
        echo "\n";
        echo "</form>\n";
    }
}
?>
